@@ -96,9 +96,11 @@ from neutron_lib.api.definitions import port_hints
 from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
+from neutron_lib.api.definitions import port_numa_affinity_policy_socket
 from neutron_lib.api.definitions import port_resource_request
 from neutron_lib.api.definitions import port_resource_request_groups
 from neutron_lib.api.definitions import port_security
+from neutron_lib.api.definitions import port_trusted_vif
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
 from neutron_lib.api.definitions import project_default_networks
@@ -119,6 +121,7 @@ from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rule_type_filter
 from neutron_lib.api.definitions import qos_rules_alias
 from neutron_lib.api.definitions import quota_check_limit
+from neutron_lib.api.definitions import quota_check_limit_default
 from neutron_lib.api.definitions import rbac_address_groups
 from neutron_lib.api.definitions import rbac_address_scope
 from neutron_lib.api.definitions import rbac_bgpvpn
@@ -145,6 +148,7 @@ from neutron_lib.api.definitions import standard_attr_segment
 from neutron_lib.api.definitions import stateful_security_group
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_dns_publish_fixed_ip
+from neutron_lib.api.definitions import subnet_external_network
 from neutron_lib.api.definitions import subnet_onboard
 from neutron_lib.api.definitions import subnet_segmentid_enforce
 from neutron_lib.api.definitions import subnet_segmentid_writable
@@ -152,10 +156,13 @@ from neutron_lib.api.definitions import subnet_service_types
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import subnetpool_prefix_ops
 from neutron_lib.api.definitions import taas
+from neutron_lib.api.definitions import tag_creation
 from neutron_lib.api.definitions import tag_ports_during_bulk_creation
+from neutron_lib.api.definitions import tap_mirror
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
 from neutron_lib.api.definitions import uplink_status_propagation
+from neutron_lib.api.definitions import uplink_status_propagation_updatable
 from neutron_lib.api.definitions import vlan_filter
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
@@ -251,9 +258,11 @@ _ALL_API_DEFINITIONS = {
     port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
+    port_numa_affinity_policy_socket,
     port_resource_request,
     port_resource_request_groups,
     port_security,
+    port_trusted_vif,
     portbindings,
     portbindings_extended,
     project_default_networks,
@@ -274,6 +283,7 @@ _ALL_API_DEFINITIONS = {
     qos_rule_type_filter,
     qos_rules_alias,
     quota_check_limit,
+    quota_check_limit_default,
     rbac_address_groups,
     rbac_address_scope,
     rbac_bgpvpn,
@@ -299,6 +309,7 @@ _ALL_API_DEFINITIONS = {
     stateful_security_group,
     subnet,
     subnet_dns_publish_fixed_ip,
+    subnet_external_network,
     subnet_onboard,
     subnet_segmentid_enforce,
     subnet_segmentid_writable,
@@ -306,10 +317,13 @@ _ALL_API_DEFINITIONS = {
     subnetpool,
     subnetpool_prefix_ops,
     taas,
+    tag_creation,
     tag_ports_during_bulk_creation,
+    tap_mirror,
     trunk,
     trunk_details,
     uplink_status_propagation,
+    uplink_status_propagation_updatable,
     vlan_filter,
     vlantransparent,
     vpn,
