@@ -10,13 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 
 from oslo_config import cfg
 import oslo_messaging as messaging
 from oslo_messaging import conffixture as messaging_conffixture
 from oslo_messaging import exceptions as oslomsg_exc
-from oslo_messaging.rpc import dispatcher
 import testtools
 
 from neutron_lib import fixture
@@ -35,18 +34,13 @@ class TestRPC(base.BaseTestCase):
     @mock.patch.object(rpc, 'RequestContextSerializer')
     @mock.patch.object(messaging, 'get_rpc_transport')
     @mock.patch.object(messaging, 'get_notification_transport')
-    @mock.patch.object(messaging, 'Notifier')
-    def test_init(self, mock_not, mock_noti_trans, mock_trans, mock_ser):
-        notifier = mock.Mock()
+    def test_init(self, mock_noti_trans, mock_trans, mock_ser):
         transport = mock.Mock()
         noti_transport = mock.Mock()
-        serializer = mock.Mock()
         conf = mock.Mock()
 
         mock_trans.return_value = transport
         mock_noti_trans.return_value = noti_transport
-        mock_ser.return_value = serializer
-        mock_not.return_value = notifier
 
         rpc.init(conf, rpc_ext_mods=['foo'])
 
@@ -55,14 +49,10 @@ class TestRPC(base.BaseTestCase):
             conf, allowed_remote_exmods=expected_mods)
         mock_noti_trans.assert_called_once_with(
             conf, allowed_remote_exmods=expected_mods)
-        mock_not.assert_called_once_with(noti_transport,
-                                         serializer=serializer)
         self.assertIsNotNone(rpc.TRANSPORT)
         self.assertIsNotNone(rpc.NOTIFICATION_TRANSPORT)
-        self.assertIsNotNone(rpc.NOTIFIER)
 
     def test_cleanup_transport_null(self):
-        rpc.NOTIFIER = mock.Mock()
         rpc.NOTIFICATION_TRANSPORT = mock.Mock()
         rpc.TRANSPORT = None
         self.assertRaises(AssertionError, rpc.cleanup)
@@ -70,20 +60,11 @@ class TestRPC(base.BaseTestCase):
 
     def test_cleanup_notification_transport_null(self):
         rpc.TRANSPORT = mock.Mock()
-        rpc.NOTIFIER = mock.Mock()
         rpc.NOTIFICATION_TRANSPORT = None
         self.assertRaises(AssertionError, rpc.cleanup)
         rpc.NOTIFICATION_TRANSPORT = mock.Mock()
 
-    def test_cleanup_notifier_null(self):
-        rpc.TRANSPORT = mock.Mock()
-        rpc.NOTIFICATION_TRANSPORT = mock.Mock()
-        rpc.NOTIFIER = None
-        self.assertRaises(AssertionError, rpc.cleanup)
-        rpc.NOTIFIER = mock.Mock()
-
     def test_cleanup(self):
-        rpc.NOTIFIER = mock.Mock()
         rpc.NOTIFICATION_TRANSPORT = mock.Mock()
         rpc.TRANSPORT = mock.Mock()
         trans_cleanup = mock.Mock()
@@ -97,33 +78,31 @@ class TestRPC(base.BaseTestCase):
         not_trans_cleanup.assert_called_once_with()
         self.assertIsNone(rpc.TRANSPORT)
         self.assertIsNone(rpc.NOTIFICATION_TRANSPORT)
-        self.assertIsNone(rpc.NOTIFIER)
 
         rpc.TRANSPORT = mock.Mock()
-        rpc.NOTIFIER = mock.Mock()
         rpc.NOTIFICATION_TRANSPORT = mock.Mock()
 
     @mock.patch.object(rpc, 'RequestContextSerializer')
-    @mock.patch.object(rpc, 'BackingOffClient')
-    def test_get_client(self, mock_client, mock_ser):
+    @mock.patch.object(messaging, 'get_rpc_client')
+    def test_get_client(self, mock_get, mock_ser):
         rpc.TRANSPORT = mock.Mock()
         tgt = mock.Mock()
         ser = mock.Mock()
-        mock_client.return_value = 'client'
+        mock_get.return_value = 'client'
         mock_ser.return_value = ser
 
         client = rpc.get_client(tgt, version_cap='1.0', serializer='foo')
 
         mock_ser.assert_called_once_with('foo')
-        mock_client.assert_called_once_with(rpc.TRANSPORT,
-                                            tgt, version_cap='1.0',
-                                            serializer=ser)
+        mock_get.assert_called_once_with(rpc.TRANSPORT,
+                                         tgt, version_cap='1.0',
+                                         serializer=ser,
+                                         client_cls=rpc.BackingOffClient)
         self.assertEqual('client', client)
 
     @mock.patch.object(rpc, 'RequestContextSerializer')
     @mock.patch.object(messaging, 'get_rpc_server')
     def test_get_server(self, mock_get, mock_ser):
-        rpc.TRANSPORT = mock.Mock()
         ser = mock.Mock()
         tgt = mock.Mock()
         ends = mock.Mock()
@@ -133,33 +112,23 @@ class TestRPC(base.BaseTestCase):
         server = rpc.get_server(tgt, ends, serializer='foo')
 
         mock_ser.assert_called_once_with('foo')
-        access_policy = dispatcher.DefaultRPCAccessPolicy
         mock_get.assert_called_once_with(rpc.TRANSPORT, tgt, ends,
-                                         'eventlet', ser,
-                                         access_policy=access_policy)
+                                         serializer=ser)
         self.assertEqual('server', server)
 
     def test_get_notifier(self):
-        rpc.NOTIFIER = mock.Mock()
-        mock_prep = mock.Mock()
-        mock_prep.return_value = 'notifier'
-        rpc.NOTIFIER.prepare = mock_prep
-
-        notifier = rpc.get_notifier('service', publisher_id='foo')
-
-        mock_prep.assert_called_once_with(publisher_id='foo')
-        self.assertEqual('notifier', notifier)
+        mock_notifier = mock.Mock(return_value=None)
+        messaging.Notifier.__init__ = mock_notifier
+        rpc.get_notifier('service', publisher_id='foo')
+        mock_notifier.assert_called_once_with(
+            mock.ANY, serializer=mock.ANY, publisher_id='foo')
 
     def test_get_notifier_null_publisher(self):
-        rpc.NOTIFIER = mock.Mock()
-        mock_prep = mock.Mock()
-        mock_prep.return_value = 'notifier'
-        rpc.NOTIFIER.prepare = mock_prep
-
-        notifier = rpc.get_notifier('service', host='bar')
-
-        mock_prep.assert_called_once_with(publisher_id='service.bar')
-        self.assertEqual('notifier', notifier)
+        mock_notifier = mock.Mock(return_value=None)
+        messaging.Notifier.__init__ = mock_notifier
+        rpc.get_notifier('service', host='bar')
+        mock_notifier.assert_called_once_with(
+            mock.ANY, serializer=mock.ANY, publisher_id='service.bar')
 
 
 class TestRequestContextSerializer(base.BaseTestCase):
@@ -288,6 +257,7 @@ class TimeoutTestCase(base.BaseTestCase):
         rpc.init(CONF)
         rpc.TRANSPORT = mock.MagicMock()
         rpc.TRANSPORT._send.side_effect = messaging.MessagingTimeout
+        rpc.TRANSPORT.conf.oslo_messaging_metrics.metrics_enabled = False
         target = messaging.Target(version='1.0', topic='testing')
         self.client = rpc.get_client(target)
         self.call_context = mock.Mock()
@@ -447,6 +417,7 @@ class CastExceptionTestCase(base.BaseTestCase):
         rpc.init(CONF)
         rpc.TRANSPORT = mock.MagicMock()
         rpc.TRANSPORT._send.side_effect = oslomsg_exc.MessageDeliveryFailure
+        rpc.TRANSPORT.conf.oslo_messaging_metrics.metrics_enabled = False
         target = messaging.Target(version='1.0', topic='testing')
         self.client = rpc.get_client(target)
         self.cast_context = mock.Mock()
